@@ -91,6 +91,8 @@ class Presence(BaseModule):
                            properties: PresenceProperties
                            ) -> None:
 
+        self._log.info('Received from %s', properties.jid)
+
         if properties.from_muc:
             # MUC occupant presences are already handled in MUC module
             return
@@ -101,7 +103,14 @@ class Presence(BaseModule):
             # handled in VCardAvatars module
             return
 
-        self._log.info('Received from %s', properties.jid)
+        jid = properties.jid.bare
+        roster_item = self._con.get_module('Roster').get_item(jid)
+
+        if roster_item is None and not properties.is_self_bare:
+            # Handle only presence from roster contacts
+            self._log.warning('Unknown presence received')
+            self._log.warning(stanza)
+            return
 
         presence_data = PresenceData.from_presence(properties)
         self._presence_store[properties.jid] = presence_data
@@ -114,14 +123,6 @@ class Presence(BaseModule):
                                             show=properties.show.value))
             return
 
-        jid = properties.jid.bare
-        roster_item = self._con.get_module('Roster').get_item(jid)
-        if not properties.is_self_bare and roster_item is None:
-            # Handle only presence from roster contacts
-            self._log.warning('Unknown presence received')
-            self._log.warning(stanza)
-            return
-
         show = properties.show.value
         if properties.type.is_unavailable:
             show = 'offline'
