@@ -20,11 +20,11 @@ from gi.repository import Gtk
 from gajim.common import app
 from gajim.common.i18n import _
 
-from .account_wizard import AccountWizard
-from .accounts import AccountsWindow
-from .builder import get_builder
-from .preferences import Preferences
-from .util import get_app_window
+from gajim.gtk.account_wizard import AccountWizard
+from gajim.gtk.accounts import AccountsWindow
+from gajim.gtk.builder import get_builder
+from gajim.gtk.preferences import Preferences
+from gajim.gtk.util import get_app_window
 
 
 class ManageProxies(Gtk.ApplicationWindow):
@@ -83,7 +83,7 @@ class ManageProxies(Gtk.ApplicationWindow):
         self._ui.settings_grid.set_sensitive(False)
         model = Gtk.ListStore(str)
         self._ui.proxies_treeview.set_model(model)
-        col = Gtk.TreeViewColumn('Proxies')
+        col = Gtk.TreeViewColumn(title='Proxies')
         self._ui.proxies_treeview.append_column(col)
         renderer = Gtk.CellRendererText()
         col.pack_start(renderer, True)
